@@ -12,7 +12,7 @@
 #' average waiting time of 1/r. This useful property allows sampling to be
 #' rapidly simulated for many taxa under this simple model in sampleRanges, by
 #' repeatedly drawing waiting times between sampling events from an exponential
-#' distribution. This is the model that is run as long as alpha, beta and
+#' distribution. This is the model that is run when alpha, beta and
 #' rTimeRatio are set to 1.
 #' 
 #' In addition to this simple model, sampleRanges also can consider a range of
@@ -32,7 +32,7 @@
 #' 
 #' The input r values will be interpreted differently based on whether one r
 #' value or per-taxon values were used. If one value was input, then it is
-#' assumed that r represent the grand mean r for entire dataset for purposes
+#' assumed that r represent the grand mean r for the entire dataset for purposes
 #' of time-varying r, such that if rTimeRatio is not equal to 1, taxa near the
 #' end and start of the dataset will have very different per-taxon mean
 #' sampling rate. If per-taxon values of r were input, then each r is consider
@@ -43,7 +43,9 @@
 #' describes the change in sampling rates from the start of the dataset to the
 #' end, while if multiple values are given for either r or rTimeRatio will
 #' instead see the value as describing the ratio at the first and last times of
-#' each taxon.
+#' each taxon. For the pure hat model, this interpretation of 'r' as a grand mean
+#' sampling means that taxa will have a sampling rate of 2*r at the mid-peak of their
+#' range, which will have considerable implications for taxonomic incompleteness.
 #' 
 #' The particular distinctions about these parameter values are important: all
 #' models simulated in sampleRanges are structured to be effectively nested
@@ -63,13 +65,13 @@
 #' et al., 2010). However, for still-living taxa at the modern day, it is
 #' unknown how much longer they may be alive (for memoryless Poisson models,
 #' there is no age-dependent extinction). The treatment of these taxa with
-#' regards to their 'hat' (the beta distribution is controlled by randLivehat;
-#' when FALSE, the beta distribution is fit so that the last appearance of live
-#' taxa (both extinct and still-alive) are fit within their ranges. When TRUE,
-#' the default option, the still-alive taxa are consider to have gotten some
+#' regards to their 'hat' (i. e. the beta distribution) is controlled by randLivehat:
+#' when ranLiveHat=FALSE, the beta distribution is fit so that the last appearance of
+#' still-alive taxa at the modern day is treated as a last appearance for calculating the hat. When TRUE,
+#' the default option, the still-alive taxa are considered to have gotten some
 #' distance between 0 and 1 through the beta distribution, as of the modern
 #' day. This point of progression is stochastically selected for each taxon by
-#' pulling a number from a uniform distribution.
+#' pulling a number from a uniform distribution, and used for calculating the hat.
 #' 
 #' Because sampling rate varies over morphotaxon ranges under any of these more
 #' complex models, sampling events cannot be quickly simulated as waiting times
@@ -104,30 +106,45 @@
 #' simulation results for some analyses, such as simulation analyses of
 #' birth-death processes. Set min.taxa=0 to remove this conditioning.
 #' 
+
+
 #' @param taxad A two-column matrix of per-taxon ranges. The five-column matrix
 #' output of simFossilTaxa can also be supplied, which will be common in
 #' simulation usages.
+
 #' @param r Instantaneous average sampling rate per lineage time units; given
 #' as a vector of length one or length equal to the number of taxa
+
 #' @param alpha Alpha parameter of beta distribution; given as a vector of
 #' length one or length equal to the number of taxa
+
 #' @param beta Beta parameter of beta distribution; given as a vector of length
 #' one or length equal to the number of taxa
+
 #' @param rTimeRatio Ratio of most recent sampling rate over earliest sampling
 #' rate; given as a vector of length one or length equal to the number of taxa
+
 #' @param modern.samp.prob Probability of sampling living taxa at the present
 #' day (time=0), see below.
+
 #' @param min.taxa Minimum number of taxa sampled. The default is 2.
+
 #' @param ranges.only If TRUE, gives taxon first and last occurrences only. If
 #' FALSE, gives the time of all sampling events as a list.
+
 #' @param minInt Minimum interval size used for simulating complex models
+
 #' @param merge.cryptic If TRUE, sampling events for cryptic species will be
 #' merged into one taxon.
+
 #' @param randLiveHat If TRUE, taxa still alive at modern day have the
 #' end-point of their 'hat' chosen from a uniform distribution.
+
 #' @param alt.method If TRUE, use the alternative method of discretizing time
 #' even if a simple model of sampling is being simulated.
+
 #' @param plot If TRUE, plots the sampling models for each taxon against time.
+
 #' @return If ranges.only is TRUE, then the output is a two-column per-taxon
 #' matrix of first and last appearances in absolute time. NAs mean the taxon
 #' was never sampled in the simulation.
@@ -272,7 +289,12 @@ sampleRanges<-function(taxad,r,alpha=1,beta=1,rTimeRatio=1,modern.samp.prob=1,mi
 	r_end<-2*r*(1-1/(rTimeRatio+1))
 	if(length(r)==1 & length(rTimeRatio)==1){
 		#thanks to Emily King and Brian Koch for helping me with this bit!
-		rTimeChange<-(r_end-r_start)/(max(timeData)-min(timeData))
+		if(max(timeData)==min(timeData)){
+			denomTime<-1
+			}else{
+			denomTime<-(max(timeData)-min(timeData))
+			}
+		rTimeChange<-(r_end-r_start)/denomTime
 		rTimeChange<-rep(rTimeChange,length(names))
 	}else{	#if there's multiple r values, multiple ratios or both...
 		dur1<-timeData[,1]-timeData[,2]
