@@ -53,7 +53,7 @@
 #' tree950 <- timeSliceTree(tree,sliceTime=950,plot=TRUE,drop.extinct=FALSE)
 #' 
 #' #use drop.extinct=T to only get the tree of lineages extant at time=950
-#' tree950 <- timeSliceTree(tree,sliceTime=950,plot=TRUE,drop.extinct=TRUE)
+#' tree950 <- timeSliceTree(tree,sliceTime=950,plot=FALSE,drop.extinct=TRUE)
 #' #now its an ultrametric tree with many fewer tips...
 #' #lets plot the lineage accumulation plot on a log scale
 #' phyloDiv(tree950,plotLogRich=TRUE)
@@ -95,7 +95,13 @@ timeSliceTree<-function(ttree,sliceTime,drop.extinct=FALSE,plot=TRUE){
 	if(drop.extinct){
 		stree1<-dropExtinct(stree,ignore.root.time=TRUE)
 	}else{stree1<-stree}
-	if(plot){layout(1:2);plot(ladderize(ttree),show.tip.label=FALSE);axisPhylo();
-		plot(ladderize(stree1),show.tip.label=FALSE);layout(1)};axisPhylo();
+	if(plot){
+		layout(1:2)
+		plot(ladderize(ttree),show.tip.label=FALSE)
+			axisPhylo()
+		plot(ladderize(stree1),show.tip.label=FALSE)
+			axisPhylo()
+		layout(1)
+		}
 	return(stree1)
 	}
